//+------------------------------------------------------------------+
//|                                                     LotsRisk.mq4 |
//|                                                             GF1D |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "GF1D"

#define LOTS_NORMAL     0
#define LOTS_TOO_BIG    1
#define LOTS_TOO_SMALL  2

//--------------------------------------------------------------------
double GetNeccessaryLotsWithRisk(int riskPercent, double sl, double price, int& error)
{
   error = LOTS_NORMAL;
   
   double ticks = MathAbs(sl - price) / MarketInfo(Symbol(), MODE_TICKSIZE),  //      
      riskAmount = AccountBalance() * riskPercent / 100.0,                    //    
      lots = riskAmount / (ticks * MarketInfo(Symbol(), MODE_TICKVALUE));     //   
   
   double maxLot = MarketInfo(Symbol(), MODE_MAXLOT),
      minLot = MarketInfo(Symbol(), MODE_MINLOT),
      lotStep = MarketInfo(Symbol(), MODE_LOTSTEP);
      
   //   
   if (lots > maxLot)
   {
      error = LOTS_TOO_BIG;
      lots = 0;
   }
   if (lots < minLot)
   {
      error = LOTS_TOO_SMALL;
      lots = 0;
   }
   
   //     
   int digits;
   if (lotStep >= 1) digits = 0;             // 1
   else  if (lotStep * 10 >= 1) digits = 1;  // 0.1
         else digits = 2;                    // 0.01
   lots = NormalizeDouble(lots, digits);
 
   return (lots);
}

